The :mod:`tricircleclient` Python API
=====================================

Usage
-----

To use tricircleclient in a project::

    >>> from tricircleclient.v1 import client
    >>> tricircle = client.Client(...)
    >>> tricircle.pod.list()

Reference
---------

For more information, see the reference:

.. toctree::
   :glob:

   api/*
